@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2015-2017,2019 Aurimas Cernius
+ * Copyright (C) 2013,2015-2017,2019-2020 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,18 +87,17 @@ MainWindow *MainWindow::present_default(IGnote & g, const Note::Ptr & note)
   if(win) {
     return win;
   }
-  Glib::RefPtr<Gio::Settings> settings = g.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
-  if(false == settings->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW)) {
+  if(false == g.preferences().open_notes_in_new_window()) {
     if (note->has_window()) {
       win = dynamic_cast<MainWindow*>(note->get_window()->host());
     }
-    else {
+    if(!win) {
       win = &g.get_window_for_note();
     }
   }
   if(!win) {
     win = &g.new_main_window();
-    win->close_on_escape(settings->get_boolean(Preferences::ENABLE_CLOSE_NOTE_ON_ESCAPE));
+    win->close_on_escape(g.preferences().enable_close_note_on_escape());
   }
   win->present_note(note);
   win->present();
@@ -108,8 +107,7 @@ MainWindow *MainWindow::present_default(IGnote & g, const Note::Ptr & note)
 bool MainWindow::use_client_side_decorations(Preferences & prefs)
 {
   if(s_use_client_side_decorations < 0) {
-    Glib::ustring setting = prefs.get_schema_settings(Preferences::SCHEMA_GNOTE)->get_string(
-      Preferences::USE_CLIENT_SIDE_DECORATIONS);
+    auto setting = prefs.use_client_side_decorations();
     if(setting == "enabled") {
       s_use_client_side_decorations = 1;
     }
